@@ -2,9 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -80,7 +78,7 @@
 /* Define if your compiler is broken.  */
 #undef MFX_PROG_CC_BUG_SIGNED_TO_UNSIGNED_CASTING
 
-/* See src/lzo_conf.h.  */
+/* Define to your byte order.  */
 #undef MFX_BYTE_ORDER
 
 /* Define to your CPU name.  */
@@ -89,9 +87,6 @@
 /* Define if your memcmp is broken.  */
 #undef NO_MEMCMP
 
-/* Define to the name of the distribution.  */
-#undef PACKAGE
-
 /* Define to `long' if <stddef.h> doesn't define.  */
 #undef ptrdiff_t
 
@@ -101,9 +96,6 @@
 /* The number of bytes in a size_t.  */
 #undef SIZEOF_SIZE_T
 
-/* Define to the version of the distribution.  */
-#undef VERSION
-
 
 
 /* Leave that blank line there!!  Autoheader needs it.
@@ -125,14 +117,34 @@
 #  undef /**/ HAVE_SYS_TIMES_H
 #endif
 
-#if defined(HAVE_ZLIB_H) && !defined(HAVE_LIBZ)
+#if !defined(HAVE_LIBZ)
 #  undef /**/ HAVE_ZLIB_H
 #endif
 
+#if defined(NO_MEMCMP)
+#  undef /**/ HAVE_MEMCMP
+#endif
+
+#if (SIZEOF_CHAR_P <= 0)
+#  undef /**/ SIZEOF_CHAR_P
+#endif
+
 #if (SIZEOF_PTRDIFF_T <= 0)
 #  undef /**/ SIZEOF_PTRDIFF_T
 #endif
 
+#if (SIZEOF_UNSIGNED <= 0)
+#  undef /**/ SIZEOF_UNSIGNED
+#endif
+
+#if (SIZEOF_UNSIGNED_LONG <= 0)
+#  undef /**/ SIZEOF_UNSIGNED_LONG
+#endif
+
+#if (SIZEOF_UNSIGNED_SHORT <= 0)
+#  undef /**/ SIZEOF_UNSIGNED_SHORT
+#endif
+
 #if (SIZEOF_SIZE_T <= 0)
 #  undef /**/ SIZEOF_SIZE_T
 #endif
