@@ -2,9 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -70,7 +68,8 @@ static const char *progname = NULL;
 static unsigned long total_files = 0;
 static unsigned long total_in = 0;
 
-static lzo_byte *safe_malloc(lzo_uint len)
+
+static lzo_byte *xmalloc(lzo_uint len)
 {
 	lzo_byte *p;
 
@@ -130,9 +129,9 @@ int do_file ( const char *in_name )
 /*
  * Step 2: allocate compression buffers and read the file
  */
-	in = safe_malloc(in_len);
-	out = safe_malloc(in_len + in_len / 64 + 16 + 3);
-	wrkmem = safe_malloc(LZO1X_1_MEM_COMPRESS);
+	in = xmalloc(in_len);
+	out = xmalloc(in_len + in_len / 64 + 16 + 3);
+	wrkmem = xmalloc(LZO1X_1_MEM_COMPRESS);
 	in_len = lzo_fread(f,in,in_len);
 	fclose(f); f = NULL;
 	printf("%s: %s: read %ld bytes\n", progname, in_name, (long) in_len);
@@ -160,7 +159,7 @@ int do_file ( const char *in_name )
  */
 	overhead  = in_len > 0xbfff ? 0xbfff : in_len;
  	overhead += in_len / 64 + 16 + 3;
-	overlap = safe_malloc(in_len + overhead);
+	overlap = xmalloc(in_len + overhead);
 
 /*
  * Step 4b: prepare data in `overlap' buffer.
@@ -191,7 +190,7 @@ int do_file ( const char *in_name )
 		 * compression by doing a temporary decompression.
 		 */
 		lzo_uint l = in_len;
-		lzo_byte *tmp = safe_malloc(l);
+		lzo_byte *tmp = xmalloc(l);
 		r = lzo1x_decompress_safe(overlap,new_len,tmp,&l,NULL);
  		if (r != LZO_E_OK || l != in_len || lzo_memcmp(in,tmp,l) != 0)
 		{
@@ -216,7 +215,7 @@ int do_file ( const char *in_name )
 		overhead = in_len / 64 + 16 + 3;
 	else
  		overhead = opt_overhead;
-	overlap = safe_malloc(in_len + overhead);
+	overlap = xmalloc(in_len + overhead);
 
 /*
  * Step 5b: prepare data in `overlap' buffer.
@@ -282,7 +281,7 @@ int main(int argc, char *argv[])
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
 	        LZO_VERSION_STRING, LZO_VERSION_DATE);
-	printf("Copyright (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer\n\n");
+	printf("Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	progname = argv[0];
 	if (i < argc && argv[i][0] == '-')
