@@ -2,8 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -74,6 +73,8 @@ lzo1y_999_compress_internal ( const lzo_byte *in , lzo_uint  in_len,
 #define USE_LZO1X
 #define USE_LZO1Y
 
+#define PARANOID
+
 
 /*************************************************************************
 //
@@ -121,7 +122,7 @@ int main(int argc, char *argv[])
 
 	printf("\nLZO real-time data compression library (v%s, %s).\n",
 	        LZO_VERSION_STRING, LZO_VERSION_DATE);
-	printf("Copyright (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer\n\n");
+	printf("Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer\n\n");
 
 	progname = argv[0];
 	if (argc < 2 || argc > 3)
@@ -331,6 +332,34 @@ int main(int argc, char *argv[])
 		}
 	}
 
+/*
+ * Step 12: verify decompression
+ */
+#ifdef PARANOID
+ 	orig_len = in_len;
+	if (best_compress == 1)
+		r = lzo1x_decompress(out,out_len,in,&orig_len,NULL);
+	else if (best_compress == 2)
+		r = lzo1y_decompress(out,out_len,in,&orig_len,NULL);
+	else
+		r = -100;
+	if (r != LZO_E_OK || orig_len != in_len)
+	{
+		/* this should NEVER happen */
+		printf("internal error - decompression failed: %d\n", r);
+		exit(1);
+	}
+	if (uncompressed_checksum != lzo_adler32(lzo_adler32(0,NULL,0),in,in_len))
+	{
+		/* this should NEVER happen */
+		printf("internal error - decompression data error\n");
+		exit(1);
+	}
+	/* Now you could also verify decompression under similar conditions as in
+	 * your application, e.g. overlapping assembler decompression etc.
+	 */
+#endif
+
 	lzo_free(in);
 	lzo_free(out);
 	lzo_free(wrkmem);
