@@ -2,6 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
+   Copyright (C) 1999 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
    Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
@@ -41,7 +42,7 @@
 #undef LZO_HAVE_CONFIG_H
 #include "minilzo.h"
 
-#if !defined(MINILZO_VERSION) || (MINILZO_VERSION != 0x1040)
+#if !defined(MINILZO_VERSION) || (MINILZO_VERSION != 0x1060)
 #  error "version mismatch in miniLZO source files"
 #endif
 
@@ -574,8 +575,11 @@ __asm__ __volatile__( \
 
 #elif (LZO_UINT_MAX <= SIZE_T_MAX) && defined(HAVE_MEMSET)
 
-#define BZERO8_PTR(s,l,n) \
-    memset((lzo_voidp)(s),0,(lzo_uint)(l)*(n))
+#if 1
+#define BZERO8_PTR(s,l,n)   memset((s),0,(lzo_uint)(l)*(n))
+#else
+#define BZERO8_PTR(s,l,n)   memset((lzo_voidp)(s),0,(lzo_uint)(l)*(n))
+#endif
 
 #else
 
@@ -627,9 +631,12 @@ lzo_assert(int expr)
  */
 
 const lzo_byte __lzo_copyright[] =
+#if !defined(__LZO_IN_MINLZO)
+    LZO_VERSION_STRING;
+#else
     "\n\n\n"
     "LZO real-time data compression library.\n"
-    "Copyright (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer\n"
+    "Copyright (C) 1996, 1997, 1998, 1999 Markus Franz Xaver Johannes Oberhumer\n"
     "<markus.oberhumer@jk.uni-linz.ac.at>\n"
     "http://wildsau.idv.uni-linz.ac.at/mfx/lzo.html\n"
     "\n"
@@ -639,11 +646,10 @@ const lzo_byte __lzo_copyright[] =
 #ifdef __cplusplus
     " __cplusplus\n"
 #endif
-#ifdef __pic__
-    " __pic__\n"
-#endif
-#ifdef __PIC__
+#if defined(__PIC__)
     " __PIC__\n"
+#elif defined(__pic__)
+    " __pic__\n"
 #endif
 #if (UINT_MAX < LZO_0xffffffffL)
     " 16BIT\n"
@@ -699,7 +705,8 @@ const lzo_byte __lzo_copyright[] =
     " by Watcom C " _LZO_MEXPAND(__WATCOMC__)
 #endif
     " $\n"
-    "$Copyright: LZO (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer $\n";
+    "$Copyright: LZO (C) 1996, 1997, 1998, 1999 Markus Franz Xaver Johannes Oberhumer $\n";
+#endif
 
 LZO_PUBLIC(const lzo_byte *)
 lzo_copyright(void)
@@ -1015,7 +1022,7 @@ static lzo_bool ptr_check(void)
     wrkmem = (lzo_byte *) LZO_PTR_ALIGN_UP(_wrkmem,sizeof(lzo_align_t));
     dict = (const lzo_bytepp) wrkmem;
 
-    d = (long) ((lzo_bytep) dict - (lzo_bytep) _wrkmem);
+    d = (long) ((const lzo_bytep) dict - (const lzo_bytep) _wrkmem);
     r &= __lzo_assert(d >= 0);
     r &= __lzo_assert(d < (long) sizeof(lzo_align_t));
 
@@ -1028,7 +1035,7 @@ static lzo_bool ptr_check(void)
     if (r == 1)
     {
 	for (i = 0; i < 8; i++)
-	    r &= __lzo_assert((lzo_voidp) (&dict[i]) == (lzo_voidp) (&wrkmem[i * sizeof(lzo_byte *)]));
+	    r &= __lzo_assert((const lzo_voidp) (&dict[i]) == (const lzo_voidp) (&wrkmem[i * sizeof(lzo_byte *)]));
     }
 
     memset(&a,0,sizeof(a));
@@ -1088,7 +1095,6 @@ _lzo_config_check(void)
 {
     lzo_bool r = 1;
     int i;
-    lzo_uint32 adler;
     union {
 	lzo_uint32 a;
 	unsigned short b;
@@ -1186,12 +1192,15 @@ _lzo_config_check(void)
 
     r &= __lzo_assert(lzo_sizeof_dict_t == sizeof(lzo_dict_t));
 
+#if defined(__LZO_IN_MINLZO)
     if (r == 1)
     {
+	lzo_uint32 adler;
 	adler = lzo_adler32(0, NULL, 0);
 	adler = lzo_adler32(adler, lzo_copyright(), 200);
-	r &= __lzo_assert(adler == 0xfc1c43c4L);
+	r &= __lzo_assert(adler == 0x7ea34377L);
     }
+#endif
 
     if (r == 1)
     {
@@ -1219,12 +1228,14 @@ _lzo_config_check(void)
 
 static lzo_bool schedule_insns_bug(void)
 {
+#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+    return 0;
+#else
     const int clone[] = {1, 2, 0};
     const int *q;
     q = clone;
-    if (*q)
-	return 0;
-    return 1;
+    return (*q) ? 0 : 1;
+#endif
 }
 
 static lzo_bool strength_reduce_bug(int *x)
