@@ -2,9 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -165,7 +163,11 @@ code_match ( LZO_COMPRESS_T *c, lzo_byte *op, lzo_uint m_len, lzo_uint m_off )
 #endif
 		c->m1a_m++;
 	}
+#if defined(LZO1Z)
+	else if (m_len <= M2_MAX_LEN && (m_off <= M2_MAX_OFFSET || m_off == c->last_m_off))
+#else
 	else if (m_len <= M2_MAX_LEN && m_off <= M2_MAX_OFFSET)
+#endif
 	{
 		assert(m_len >= 3);
 #if defined(LZO1X)
@@ -458,7 +460,27 @@ void assert_match( const lzo_swd_t *swd, lzo_uint m_len, lzo_uint m_off )
 static void
 better_match ( const lzo_swd_t *swd, lzo_uint *m_len, lzo_uint *m_off )
 {
-	if (*m_len <= 3 || *m_off <= M2_MAX_OFFSET)
+#if defined(LZO1Z)
+	const LZO_COMPRESS_T *c = swd->c;
+#endif
+
+	if (*m_len <= M2_MIN_LEN)
+		return;
+#if defined(LZO1Z)
+	if (*m_off == c->last_m_off && *m_len <= M2_MAX_LEN)
+		return;
+#if 1
+	if (*m_len >= M2_MIN_LEN + 1 && *m_len <= M2_MAX_LEN + 1 &&
+		c->last_m_off && swd->best_off[*m_len-1] == c->last_m_off)
+	{
+		*m_len = *m_len - 1;
+		*m_off = swd->best_off[*m_len];
+		return;
+	}
+#endif
+#endif
+
+	if (*m_off <= M2_MAX_OFFSET)
 		return;
 
 #if 1
@@ -634,7 +656,6 @@ lzo1x_999_compress_internal ( const lzo_byte *in , lzo_uint  in_len,
 
 
 
-
 		/* shall we try a lazy match ? */
 		ahead = 0;
 		if (try_lazy <= 0 || m_len >= max_lazy)
@@ -671,6 +692,11 @@ lzo1x_999_compress_internal ( const lzo_byte *in , lzo_uint  in_len,
 			assert(c->look > 0);
 			assert(ii + lit + ahead == c->bp);
 
+#if defined(LZO1Z)
+			if (m_off == c->last_m_off && c->m_off != c->last_m_off)
+				if (m_len >= M2_MIN_LEN && m_len <= M2_MAX_LEN)
+					c->m_len = 0;
+#endif
 			if (c->m_len < m_len)
 				continue;
 #if 1
