@@ -2,9 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -138,7 +136,7 @@ static lzo_bool basic_integral_check(void)
 	}
 
 #if 0
-	/* for some reason this fails on a Cray */
+	/* for some reason this fails on a Cray ??? */
 	r &= __lzo_assert(LZO_BYTE(257) == 1);
 	r &= __lzo_assert(LZO_USHORT(65537L) == 1);
 #endif
@@ -210,7 +208,7 @@ static lzo_bool ptr_check(void)
 	wrkmem = (lzo_byte *) LZO_PTR_ALIGN_UP(_wrkmem,sizeof(lzo_align_t));
 	dict = (const lzo_bytepp) wrkmem;
 
-	d = (long) ((lzo_bytep) dict - (lzo_bytep) _wrkmem);
+	d = (long) ((const lzo_bytep) dict - (const lzo_bytep) _wrkmem);
 	r &= __lzo_assert(d >= 0);
 	r &= __lzo_assert(d < (long) sizeof(lzo_align_t));
 
@@ -224,7 +222,7 @@ static lzo_bool ptr_check(void)
 	if (r == 1)
 	{
 		for (i = 0; i < 8; i++)
-			r &= __lzo_assert((lzo_voidp) (&dict[i]) == (lzo_voidp) (&wrkmem[i * sizeof(lzo_byte *)]));
+			r &= __lzo_assert((const lzo_voidp) (&dict[i]) == (const lzo_voidp) (&wrkmem[i * sizeof(lzo_byte *)]));
 	}
 
 	/* check BZERO8_PTR and that NULL == 0 */
@@ -292,7 +290,6 @@ _lzo_config_check(void)
 {
 	lzo_bool r = 1;
 	int i;
-	lzo_uint32 adler;
 	union {
 		lzo_uint32 a;
 		unsigned short b;
@@ -394,13 +391,17 @@ _lzo_config_check(void)
 
 	r &= __lzo_assert(lzo_sizeof_dict_t == sizeof(lzo_dict_t));
 
+	/* save space and don't require linking in the lzo_adler32() function */
+#if defined(__LZO_IN_MINLZO)
 	/* check the lzo_adler32() function */
 	if (r == 1)
 	{
+		lzo_uint32 adler;
 		adler = lzo_adler32(0, NULL, 0);
 		adler = lzo_adler32(adler, lzo_copyright(), 200);
-		r &= __lzo_assert(adler == 0xfc1c43c4L);
+		r &= __lzo_assert(adler == 0x7ea34377L);
 	}
+#endif
 
 	/* check for the gcc schedule-insns optimization bug */
 	if (r == 1)
@@ -432,12 +433,15 @@ _lzo_config_check(void)
 
 static lzo_bool schedule_insns_bug(void)
 {
+#if defined(__BOUNDS_CHECKING_ON) || defined(__CHECKER__)
+	/* for some reason checker complains about uninitialized memory access */
+	return 0;
+#else
 	const int clone[] = {1, 2, 0};
 	const int *q;
 	q = clone;
-	if (*q)
-    	return 0;
-	return 1;
+	return (*q) ? 0 : 1;
+#endif
 }
 
 
