@@ -2,8 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -49,9 +48,13 @@ lzo_assert(int expr)
 .*/
 
 const lzo_byte __lzo_copyright[] =
+#if !defined(__LZO_IN_MINLZO)
+	/* save space as some people want a really small decompressor */
+    LZO_VERSION_STRING;
+#else
 	"\n\n\n"
 	"LZO real-time data compression library.\n"
-	"Copyright (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer\n"
+	"Copyright (C) 1996, 1997, 1998, 1999 Markus Franz Xaver Johannes Oberhumer\n"
 	"<markus.oberhumer@jk.uni-linz.ac.at>\n"
 	"http://wildsau.idv.uni-linz.ac.at/mfx/lzo.html\n"
 	"\n"
@@ -61,11 +64,10 @@ const lzo_byte __lzo_copyright[] =
 #ifdef __cplusplus
 	" __cplusplus\n"
 #endif
-#ifdef __pic__
-	" __pic__\n"
-#endif
-#ifdef __PIC__
+#if defined(__PIC__)
 	" __PIC__\n"
+#elif defined(__pic__)
+	" __pic__\n"
 #endif
 #if (UINT_MAX < LZO_0xffffffffL)
 	" 16BIT\n"
@@ -122,7 +124,8 @@ const lzo_byte __lzo_copyright[] =
 	" by Watcom C " _LZO_MEXPAND(__WATCOMC__)
 #endif
 	" $\n"
-	"$Copyright: LZO (C) 1996, 1997, 1998 Markus Franz Xaver Johannes Oberhumer $\n";
+	"$Copyright: LZO (C) 1996, 1997, 1998, 1999 Markus Franz Xaver Johannes Oberhumer $\n";
+#endif
 
 LZO_PUBLIC(const lzo_byte *)
 lzo_copyright(void)
