@@ -2,9 +2,7 @@
 
    This file is part of the LZO real-time data compression library.
 
-   Copyright (C) 1998 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1997 Markus Franz Xaver Johannes Oberhumer
-   Copyright (C) 1996 Markus Franz Xaver Johannes Oberhumer
+   Copyright (C) 1996-1999 Markus Franz Xaver Johannes Oberhumer
 
    The LZO library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -52,11 +50,11 @@ long align_test(lzo_byte *block, lzo_uint len, lzo_uint step)
 {
 	lzo_byte *b1 = block;
 	lzo_byte *b2 = block;
-	lzo_byte *k1;
-	lzo_byte *k2;
+	lzo_byte *k1 = NULL;
+	lzo_byte *k2 = NULL;
 	lzo_byte *k;
 	lzo_byte *x;
-	lzo_uint offset;
+	lzo_uint offset = 0;
 	long i = 0;
 
 	assert(step > 0);
